==> huaweicloudsdkcodeartsdeploy-3.1.75-py2.py3-none-any.whl: huaweicloudsdkcodeartsdeploy/v2/model/show_execution_params_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowExecutionParamsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'task_id': 'str',
        'record_id': 'str'
    }

    attribute_map = {
        'task_id': 'task_id',
        'record_id': 'record_id'
    }

    def __init__(self, task_id=None, record_id=None):
        """ShowExecutionParamsRequest

        The model defined in huaweicloud sdk

        :param task_id: 任务id
        :type task_id: str
        :param record_id: 执行记录id
        :type record_id: str
        """
        
        

        self._task_id = None
        self._record_id = None
        self.discriminator = None

        self.task_id = task_id
        if record_id is not None:
            self.record_id = record_id

    @property
    def task_id(self):
        """Gets the task_id of this ShowExecutionParamsRequest.

        任务id

        :return: The task_id of this ShowExecutionParamsRequest.
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this ShowExecutionParamsRequest.

        任务id

        :param task_id: The task_id of this ShowExecutionParamsRequest.
        :type task_id: str
        """
        self._task_id = task_id

    @property
    def record_id(self):
        """Gets the record_id of this ShowExecutionParamsRequest.

        执行记录id

        :return: The record_id of this ShowExecutionParamsRequest.
        :rtype: str
        """
        return self._record_id

    @record_id.setter
    def record_id(self, record_id):
        """Sets the record_id of this ShowExecutionParamsRequest.

        执行记录id

        :param record_id: The record_id of this ShowExecutionParamsRequest.
        :type record_id: str
        """
        self._record_id = record_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowExecutionParamsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcodeartsdeploy-3.1.146-py2.py3-none-any.whl: huaweicloudsdkcodeartsdeploy/v2/model/show_execution_params_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowExecutionParamsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'task_id': 'str',
        'record_id': 'str'
    }

    attribute_map = {
        'task_id': 'task_id',
        'record_id': 'record_id'
    }

    def __init__(self, task_id=None, record_id=None):
        r"""ShowExecutionParamsRequest

        The model defined in huaweicloud sdk

        :param task_id: 任务id
        :type task_id: str
        :param record_id: 执行记录id
        :type record_id: str
        """
        
        

        self._task_id = None
        self._record_id = None
        self.discriminator = None

        self.task_id = task_id
        if record_id is not None:
            self.record_id = record_id

    @property
    def task_id(self):
        r"""Gets the task_id of this ShowExecutionParamsRequest.

        任务id

        :return: The task_id of this ShowExecutionParamsRequest.
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        r"""Sets the task_id of this ShowExecutionParamsRequest.

        任务id

        :param task_id: The task_id of this ShowExecutionParamsRequest.
        :type task_id: str
        """
        self._task_id = task_id

    @property
    def record_id(self):
        r"""Gets the record_id of this ShowExecutionParamsRequest.

        执行记录id

        :return: The record_id of this ShowExecutionParamsRequest.
        :rtype: str
        """
        return self._record_id

    @record_id.setter
    def record_id(self, record_id):
        r"""Sets the record_id of this ShowExecutionParamsRequest.

        执行记录id

        :param record_id: The record_id of this ShowExecutionParamsRequest.
        :type record_id: str
        """
        self._record_id = record_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowExecutionParamsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
